Class: Google::Devtools::Cloudtrace::V1::ListTracesRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb

Overview

The request message for the +ListTraces+ method. All fields are required unless specified.

Defined Under Namespace

Modules: ViewType

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeGoogle::Protobuf::Timestamp



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135

class ListTracesRequest
  # Type of data returned for traces in the list.
  module ViewType
    # Default is +MINIMAL+ if unspecified.
    VIEW_TYPE_UNSPECIFIED = 0

    # Minimal view of the trace record that contains only the project
    # and trace IDs.
    MINIMAL = 1

    # Root span view of the trace record that returns the root spans along
    # with the minimal trace data.
    ROOTSPAN = 2

    # Complete view of the trace record that contains the actual trace data.
    # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method
    # using the ID of each listed trace.
    COMPLETE = 3
  end
end

#filterString



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135

class ListTracesRequest
  # Type of data returned for traces in the list.
  module ViewType
    # Default is +MINIMAL+ if unspecified.
    VIEW_TYPE_UNSPECIFIED = 0

    # Minimal view of the trace record that contains only the project
    # and trace IDs.
    MINIMAL = 1

    # Root span view of the trace record that returns the root spans along
    # with the minimal trace data.
    ROOTSPAN = 2

    # Complete view of the trace record that contains the actual trace data.
    # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method
    # using the ID of each listed trace.
    COMPLETE = 3
  end
end

#order_byString



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135

class ListTracesRequest
  # Type of data returned for traces in the list.
  module ViewType
    # Default is +MINIMAL+ if unspecified.
    VIEW_TYPE_UNSPECIFIED = 0

    # Minimal view of the trace record that contains only the project
    # and trace IDs.
    MINIMAL = 1

    # Root span view of the trace record that returns the root spans along
    # with the minimal trace data.
    ROOTSPAN = 2

    # Complete view of the trace record that contains the actual trace data.
    # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method
    # using the ID of each listed trace.
    COMPLETE = 3
  end
end

#page_sizeInteger



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135

class ListTracesRequest
  # Type of data returned for traces in the list.
  module ViewType
    # Default is +MINIMAL+ if unspecified.
    VIEW_TYPE_UNSPECIFIED = 0

    # Minimal view of the trace record that contains only the project
    # and trace IDs.
    MINIMAL = 1

    # Root span view of the trace record that returns the root spans along
    # with the minimal trace data.
    ROOTSPAN = 2

    # Complete view of the trace record that contains the actual trace data.
    # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method
    # using the ID of each listed trace.
    COMPLETE = 3
  end
end

#page_tokenString



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135

class ListTracesRequest
  # Type of data returned for traces in the list.
  module ViewType
    # Default is +MINIMAL+ if unspecified.
    VIEW_TYPE_UNSPECIFIED = 0

    # Minimal view of the trace record that contains only the project
    # and trace IDs.
    MINIMAL = 1

    # Root span view of the trace record that returns the root spans along
    # with the minimal trace data.
    ROOTSPAN = 2

    # Complete view of the trace record that contains the actual trace data.
    # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method
    # using the ID of each listed trace.
    COMPLETE = 3
  end
end

#project_idString



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135

class ListTracesRequest
  # Type of data returned for traces in the list.
  module ViewType
    # Default is +MINIMAL+ if unspecified.
    VIEW_TYPE_UNSPECIFIED = 0

    # Minimal view of the trace record that contains only the project
    # and trace IDs.
    MINIMAL = 1

    # Root span view of the trace record that returns the root spans along
    # with the minimal trace data.
    ROOTSPAN = 2

    # Complete view of the trace record that contains the actual trace data.
    # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method
    # using the ID of each listed trace.
    COMPLETE = 3
  end
end

#start_timeGoogle::Protobuf::Timestamp



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135

class ListTracesRequest
  # Type of data returned for traces in the list.
  module ViewType
    # Default is +MINIMAL+ if unspecified.
    VIEW_TYPE_UNSPECIFIED = 0

    # Minimal view of the trace record that contains only the project
    # and trace IDs.
    MINIMAL = 1

    # Root span view of the trace record that returns the root spans along
    # with the minimal trace data.
    ROOTSPAN = 2

    # Complete view of the trace record that contains the actual trace data.
    # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method
    # using the ID of each listed trace.
    COMPLETE = 3
  end
end

#viewGoogle::Devtools::Cloudtrace::V1::ListTracesRequest::ViewType



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135

class ListTracesRequest
  # Type of data returned for traces in the list.
  module ViewType
    # Default is +MINIMAL+ if unspecified.
    VIEW_TYPE_UNSPECIFIED = 0

    # Minimal view of the trace record that contains only the project
    # and trace IDs.
    MINIMAL = 1

    # Root span view of the trace record that returns the root spans along
    # with the minimal trace data.
    ROOTSPAN = 2

    # Complete view of the trace record that contains the actual trace data.
    # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method
    # using the ID of each listed trace.
    COMPLETE = 3
  end
end