Class: Google::Devtools::Cloudtrace::V1::ListTracesRequest
- Inherits:
-
Object
- Object
- Google::Devtools::Cloudtrace::V1::ListTracesRequest
- Defined in:
- lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb
Overview
The request message for the +ListTraces+ method. All fields are required unless specified.
Defined Under Namespace
Modules: ViewType
Instance Attribute Summary collapse
-
#end_time ⇒ Google::Protobuf::Timestamp
Start of the time interval (inclusive) during which the trace data was collected from the application.
-
#filter ⇒ String
An optional filter for the request.
-
#order_by ⇒ String
Field used to sort the returned traces.
-
#page_size ⇒ Integer
Maximum number of traces to return.
-
#page_token ⇒ String
Token identifying the page of results to return.
-
#project_id ⇒ String
ID of the Cloud project where the trace data is stored.
-
#start_time ⇒ Google::Protobuf::Timestamp
End of the time interval (inclusive) during which the trace data was collected from the application.
-
#view ⇒ Google::Devtools::Cloudtrace::V1::ListTracesRequest::ViewType
Type of data returned for traces in the list.
Instance Attribute Details
#end_time ⇒ Google::Protobuf::Timestamp
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135 class ListTracesRequest # Type of data returned for traces in the list. module ViewType # Default is +MINIMAL+ if unspecified. VIEW_TYPE_UNSPECIFIED = 0 # Minimal view of the trace record that contains only the project # and trace IDs. MINIMAL = 1 # Root span view of the trace record that returns the root spans along # with the minimal trace data. ROOTSPAN = 2 # Complete view of the trace record that contains the actual trace data. # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method # using the ID of each listed trace. COMPLETE = 3 end end |
#filter ⇒ String
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135 class ListTracesRequest # Type of data returned for traces in the list. module ViewType # Default is +MINIMAL+ if unspecified. VIEW_TYPE_UNSPECIFIED = 0 # Minimal view of the trace record that contains only the project # and trace IDs. MINIMAL = 1 # Root span view of the trace record that returns the root spans along # with the minimal trace data. ROOTSPAN = 2 # Complete view of the trace record that contains the actual trace data. # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method # using the ID of each listed trace. COMPLETE = 3 end end |
#order_by ⇒ String
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135 class ListTracesRequest # Type of data returned for traces in the list. module ViewType # Default is +MINIMAL+ if unspecified. VIEW_TYPE_UNSPECIFIED = 0 # Minimal view of the trace record that contains only the project # and trace IDs. MINIMAL = 1 # Root span view of the trace record that returns the root spans along # with the minimal trace data. ROOTSPAN = 2 # Complete view of the trace record that contains the actual trace data. # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method # using the ID of each listed trace. COMPLETE = 3 end end |
#page_size ⇒ Integer
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135 class ListTracesRequest # Type of data returned for traces in the list. module ViewType # Default is +MINIMAL+ if unspecified. VIEW_TYPE_UNSPECIFIED = 0 # Minimal view of the trace record that contains only the project # and trace IDs. MINIMAL = 1 # Root span view of the trace record that returns the root spans along # with the minimal trace data. ROOTSPAN = 2 # Complete view of the trace record that contains the actual trace data. # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method # using the ID of each listed trace. COMPLETE = 3 end end |
#page_token ⇒ String
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135 class ListTracesRequest # Type of data returned for traces in the list. module ViewType # Default is +MINIMAL+ if unspecified. VIEW_TYPE_UNSPECIFIED = 0 # Minimal view of the trace record that contains only the project # and trace IDs. MINIMAL = 1 # Root span view of the trace record that returns the root spans along # with the minimal trace data. ROOTSPAN = 2 # Complete view of the trace record that contains the actual trace data. # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method # using the ID of each listed trace. COMPLETE = 3 end end |
#project_id ⇒ String
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135 class ListTracesRequest # Type of data returned for traces in the list. module ViewType # Default is +MINIMAL+ if unspecified. VIEW_TYPE_UNSPECIFIED = 0 # Minimal view of the trace record that contains only the project # and trace IDs. MINIMAL = 1 # Root span view of the trace record that returns the root spans along # with the minimal trace data. ROOTSPAN = 2 # Complete view of the trace record that contains the actual trace data. # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method # using the ID of each listed trace. COMPLETE = 3 end end |
#start_time ⇒ Google::Protobuf::Timestamp
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135 class ListTracesRequest # Type of data returned for traces in the list. module ViewType # Default is +MINIMAL+ if unspecified. VIEW_TYPE_UNSPECIFIED = 0 # Minimal view of the trace record that contains only the project # and trace IDs. MINIMAL = 1 # Root span view of the trace record that returns the root spans along # with the minimal trace data. ROOTSPAN = 2 # Complete view of the trace record that contains the actual trace data. # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method # using the ID of each listed trace. COMPLETE = 3 end end |
#view ⇒ Google::Devtools::Cloudtrace::V1::ListTracesRequest::ViewType
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/google/cloud/trace/v1/doc/google/devtools/cloudtrace/v1/trace.rb', line 135 class ListTracesRequest # Type of data returned for traces in the list. module ViewType # Default is +MINIMAL+ if unspecified. VIEW_TYPE_UNSPECIFIED = 0 # Minimal view of the trace record that contains only the project # and trace IDs. MINIMAL = 1 # Root span view of the trace record that returns the root spans along # with the minimal trace data. ROOTSPAN = 2 # Complete view of the trace record that contains the actual trace data. # This is equivalent to calling the REST +get+ or RPC +GetTrace+ method # using the ID of each listed trace. COMPLETE = 3 end end |